pub struct MessageHub { /* private fields */ }Expand description
The central message hub
Implementations
Sourceimpl MessageHub
impl MessageHub
pub fn new() -> Arc<Self>
Sourcepub fn clone_inner(&self) -> Self
pub fn clone_inner(&self) -> Self
Get a clone of this hub that shares the same connection map. Used by NatsBus to give its delivery listener access to connected devices.
Sourcepub fn connect(&self, uuid: Uuid) -> Receiver<DeviceEvent>
pub fn connect(&self, uuid: Uuid) -> Receiver<DeviceEvent>
Register a new connection, returns a receiver
Sourcepub fn disconnect(&self, uuid: &Uuid)
pub fn disconnect(&self, uuid: &Uuid)
Disconnect a device
Sourcepub fn deliver(&self, uuid: &Uuid, event: DeviceEvent)
pub fn deliver(&self, uuid: &Uuid, event: DeviceEvent)
Deliver an event to a specific device
Sourcepub fn deliver_many(&self, uuids: &[Uuid], event: DeviceEvent)
pub fn deliver_many(&self, uuids: &[Uuid], event: DeviceEvent)
Deliver an event to multiple devices
Sourcepub fn is_online(&self, uuid: &Uuid) -> bool
pub fn is_online(&self, uuid: &Uuid) -> bool
Check if a device is currently online (has an active connection)
Sourcepub fn online_count(&self) -> usize
pub fn online_count(&self) -> usize
Get count of online devices
Sourcepub fn online_devices(&self) -> Vec<Uuid>
pub fn online_devices(&self) -> Vec<Uuid>
Get all online device UUIDs